@@ -279,8 +279,10 @@ static PyObject *TagSecKeys(PyObject *Self,PyObject *Args)
       const char *End = Start;
       for (; End < Stop && *End != ':'; End++);
 
-      PyObject *Obj;
-      PyList_Append(List,Obj = PyString_FromStringAndSize(Start,End-Start));
+      PyObject *Obj = PyString_FromStringAndSize(Start, End-Start);
+      if (Obj == nullptr)
+          return Py_DECREF(List), nullptr;
+      PyList_Append(List, Obj);
       Py_DECREF(Obj);
    }
    return List;
@@ -487,7 +489,7 @@ static PyObject *TagFileEnter(PyObject *self, PyObject *args)
 // ---------------------------------------------------------------------
 static PyObject *TagSecNew(PyTypeObject *type,PyObject *Args,PyObject *kwds) {
    char *Data;
-   int Len;
+   Py_ssize_t Len;
    char Bytes = 0;
    char *kwlist[] = {"text", "bytes", 0};
 
@@ -534,7 +536,6 @@ static PyObject *TagSecNew(PyTypeObject *type,PyObject *Args,PyObject *kwds) {
 
 static PyObject *TagFileNew(PyTypeObject *type,PyObject *Args,PyObject *kwds)
 {
-   TagFileData *New;
    PyObject *File = 0;
    char Bytes = 0;
 
@@ -558,7 +559,7 @@ static PyObject *TagFileNew(PyTypeObject *type,PyObject *Args,PyObject *kwds)
       return 0;
    }
 
-   New = (TagFileData*)type->tp_alloc(type, 0);
+   PyApt_UniqueObject<TagFileData> New((TagFileData*)type->tp_alloc(type, 0));
    if (fileno != -1)
    {
 #ifdef APT_HAS_GZIP
@@ -596,7 +597,7 @@ static PyObject *TagFileNew(PyTypeObject *type,PyObject *Args,PyObject *kwds)
    // Create the section
    New->Section = (TagSecData*)(&PyTagSection_Type)->tp_alloc(&PyTagSection_Type, 0);
    new (&New->Section->Object) pkgTagSection();
-   New->Section->Owner = New;
+   New->Section->Owner = New.get();
    Py_INCREF(New->Section->Owner);
    New->Section->Data = 0;
    New->Section->Bytes = Bytes;
@@ -605,7 +606,7 @@ static PyObject *TagFileNew(PyTypeObject *type,PyObject *Args,PyObject *kwds)
    Py_XINCREF(New->Section->Encoding);
 #endif
 
-   return HandleErrors(New);
+   return HandleErrors(New.release());
 }
 									/*}}}*/
 
