@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import os
 import subprocess
@@ -19,11 +19,11 @@ class PackagePep484TestCase(unittest.TestCase):
     def test_pep484_clean(self):
         # FIXME: check all of it
         top_src_dir = os.path.join(os.path.dirname(__file__), "..", "apt")
-        # FIXME: add pyi file for apt_pkg to get rid of the
-        # --ignore-missing-imports
+        os.environ["MYPYPATH"] = os.path.join(os.path.dirname(__file__),
+                                              "..", "typehinting")
         self.assertEqual(
             subprocess.call(
-                ["mypy", "--ignore-missing-imports", top_src_dir]), 0)
+                ["mypy", "--strict", top_src_dir]), 0)
 
 
 if __name__ == "__main__":
